@@ -187,21 +187,21 @@ Usage:
         if not (data_level and isinstance(data_level, str)):
             raise InvalidParameterException("data_level")
         if data_level == "sample":
-            sample_df = self.merge_sample_metadata()
+            sample_df = self._merge_sample_metadata()
             return sample_df
         if data_level == "dataset":
-            dataset_df = self.merge_dataset_metadata()
+            dataset_df = self._merge_dataset_metadata()
             return dataset_df
         if data_level == "data_matrix":
-            datamatrix_df = self.merge_data_matrix()
+            datamatrix_df = self._merge_data_matrix()
             return datamatrix_df
         if data_level == "feature":
-            feature_df = self.merge_feature_metadata()
+            feature_df = self._merge_feature_metadata()
             return feature_df
         raise InvalidCohortMergeOperation
 
     @deprecated(reason="use function merge_data")
-    def merge_sample_metadata(self) -> pd.DataFrame:
+    def _merge_sample_metadata(self) -> pd.DataFrame:
         """
         Function to merge the sample level metadata from all the gct files in a cohort.
         Returns:
@@ -237,7 +237,7 @@ Usage:
         return self.core_obj.is_valid(self._cohort_path)
 
     @deprecated(reason="use function merge_data")
-    def merge_feature_metadata(self) -> pd.DataFrame:
+    def _merge_feature_metadata(self) -> pd.DataFrame:
         """
         Function to merge the feature level metadata from all the gct files in a cohort.
         Returns:
@@ -253,7 +253,7 @@ Usage:
         return self.core_obj.merge_feature_metadata(self._cohort_path)
 
     @deprecated(reason="use function merge_data")
-    def merge_dataset_metadata(self) -> pd.DataFrame:
+    def _merge_dataset_metadata(self) -> pd.DataFrame:
         """
         Function to merge the dataset level metadata from all the gct files in a cohort.
         Returns:
@@ -269,7 +269,7 @@ Usage:
         return self.core_obj.merge_dataset_metadata(self._cohort_path)
 
     @deprecated(reason="use function merge_data")
-    def merge_data_matrix(self) -> pd.DataFrame:
+    def _merge_data_matrix(self) -> pd.DataFrame:
         """
         Function to merge the data matrix metadata from all the gct files in a cohort.
         Returns:
