@@ -23,6 +23,13 @@ DATA_TYPES = {
     ]
 }
 
+# validation flow files url github
+VALIDATION_FLOW_FILES_URL = (
+    "https://raw.githubusercontent.com/ElucidataInc/PublicAssets/master/"
+    + "internal-user/validation_full_flow_files"
+)
+
+
 # endpoints
 CONSTANTS_ENDPOINT = "/constants"
 REPOSITORIES_ENDPOINT = "/repositories"
@@ -110,6 +117,20 @@ FILE_FORMAT_CONSTANTS_URL = (
     "https://elucidatainc.github.io/PublicAssets/file_format_constants.txt"
 )
 
+VALIDATION_STATUS_FILE_NAME = "validation_status.txt"
+
+# this constant is used as a base url for getting data files for
+# testing ingestion functionality
+BASE_TEST_FORMAT_CONSTANTS_URL = (
+    "https://raw.githubusercontent.com/ElucidataInc/PublicAssets/master/"
+    + "internal-user/add_dataset_test_file"
+)
+
+ENCRYPTION_KEY_URL = (
+    "https://raw.githubusercontent.com/ElucidataInc/PublicAssets/"
+    + "56440d3be03afe700af65d41e7fdf610befccce9/key/Encryptionkey.key"
+)
+
 COMPRESSION_TYPES = [
     ".br," ".bz2",
     ".bz",
@@ -148,14 +169,11 @@ NOT_NEEDED_SCHEMA_FIELDS = [
     "timestamp_",
 ]
 
+
 OMIXATLAS_CATEGORY_VALS = ["private", "public", "diy_poa"]
 
 VALIDATION_LEVEL_CONSTANTS = {"advanced": "value", "basic": "schema"}
 
-BASE_TEST_FORMAT_CONSTANTS_URL = "https://github.com/ElucidataInc/PublicAssets/blob/master/internal-user/add_dataset_test_file"
-
-BASE_TEST_META_CONST = "https://raw.githubusercontent.com/ElucidataInc/PublicAssets/master/internal-user/add_dataset_test_file"
-
 ELUCIDATA_LOGO_URL = (
     "https://elucidatainc.github.io/PublicAssets/dashboardFrontend/elucidata-logo.svg"
 )
@@ -168,6 +186,15 @@ SCHEMA_WRITE_SUCCESS = (
 
 SCHEMA_INSERT_SUCCESS = "Schema has been Inserted. Please use get_schema functionality to get the inserted schema."
 
+DATA_COMMIT_MESSAGE = (
+    "Your ingestion request is successfully logged. "
+    + "You can go to ingestion monitoring dashboard for tracking it's status."
+)
+
+WAIT_FOR_COMMIT = (
+    "Please wait for 30 seconds while your ingestion request is getting logged."
+)
+
 
 REPORT_GENERATION_SUPPORTED_REPOS = ["geo"]
 
