@@ -54,6 +54,15 @@ class UnauthorizedException(Exception):
         return "Expired or Invalid Token"
 
 
+class ValidationError(Exception):
+    detail = app_err_info.VALIDATION_ERROR
+
+    def __init__(self, title=None, detail=None):
+        self.title = app_err_info.WRONG_PARAMS_EXCEPTION_TITLE
+        if detail:
+            self.detail = detail
+
+
 class UnfinishedQueryException(Exception):
     def __init__(self, query_id):
         self.query_id = query_id
