@@ -28,6 +28,8 @@ from bs4 import BeautifulSoup
 import contextlib
 import joblib
 import urllib
+import pandas as pd
+import polly.http_response_codes as http_codes
 
 
 def get_platform_value_from_env(
@@ -78,6 +80,48 @@ def get_sts_creds(sts_dict: dict) -> dict:
         raise InvalidParameterException("sts_dict")
 
 
+def merge_dataframes_from_list(df_list: list) -> pd.DataFrame:
+    """Takes a list of dfs as argument
+    Returns:
+        pd.DataFrame: Merge all of them into 1 DF
+    """
+    if df_list:
+        res_df = pd.concat(df_list, axis=0, ignore_index=True)
+    else:
+        res_df = pd.DataFrame()
+    return res_df
+
+
+def merge_dicts_from_list(dict_list: list) -> dict:
+    """Takes a list of dicts as argument
+    Returns:
+        dict: Merge all of them into 1 dict
+    """
+    res_dict = {}
+    for dict in dict_list:
+        res_dict.update(dict)
+    return res_dict
+
+
+def display_df_from_list(val_list: list, column_name_in_df: str):
+    """Display dataframe from a flat list and put column name of
+    Dataframe that is passed in arguments
+    Example :-
+    lst = ["abc", "def", "ghi"]
+    This lst needs to be converted to dataframe.
+    column_name is passed as parameter
+    Args:
+        val_list (list): list of values to put in dataframe
+        column_name_in_df (str): column name for the dataframe
+    """
+    val_df = pd.DataFrame(val_list, columns=[column_name_in_df])
+
+    with pd.option_context(
+        "display.max_rows", 800, "display.max_columns", 800, "display.width", 1200
+    ):
+        print(val_df)
+
+
 def upload_to_S3(cloud_path: str, local_path: str, credentials: dict) -> None:
     """
     Function to upload file/folder to S3 cloud path
@@ -426,17 +470,26 @@ def split_workspace_path(absolute_path: str) -> tuple:
     return workspace_id, workspace_path
 
 
-def make_private_link(workspace_id: int, workspace_path: str, constant_url: str) -> str:
+def make_private_link(
+    workspace_id: int, workspace_path: str, constant_url: str, report_id: str
+) -> str:
     """
-    Function to construct and return a private link for a file in workspace
+    Function to construct and return a private link for a file in workspace.
     """
-    file_element = {"file": f"/projects/{workspace_id}/files/{workspace_path}"}
-    private_access_link = f"{constant_url}/workspaces?id={workspace_id}&{urllib.parse.urlencode(file_element)}&preview=true"
-    return private_access_link
+    file_element = {"path": f"/projects/{workspace_id}/files/{workspace_path}"}
+    if report_id:
+        return f"{constant_url}/restricted/file?id={workspace_id}&{urllib.parse.urlencode(file_element)}&report_id={report_id}"
+    else:
+        return f"{constant_url}/restricted/file?id={workspace_id}&{urllib.parse.urlencode(file_element)}"
 
 
 def change_file_access(
-    self, access_key: str, workspace_id: int, workspace_path: str, access_url: str
+    self,
+    access_key: str,
+    workspace_id: int,
+    workspace_path: str,
+    access_url: str,
+    report_id: str,
 ) -> str:
     """
     Function to change the file access as per the access_key and returns the final access url
@@ -448,7 +501,9 @@ def change_file_access(
         # API call to change the file access to private
         response = self.session.get(url, params=params)
         error_handler(response)
-        final_url = make_private_link(workspace_id, workspace_path, access_url)
+        final_url = make_private_link(
+            workspace_id, workspace_path, access_url, report_id
+        )
     else:
         params = {"action": "share", "access_type": "global"}
         url = f"{self.base_url}/projects/{workspace_id}/files/{workspace_path}"
@@ -629,7 +684,6 @@ def decode_id_token(tokenID: str) -> dict:
 
 
 def makeRequestCookieForPollyJob(job_data: json) -> json:
-
     """
     Generates the cookie required request for polly job API
 
@@ -732,6 +786,37 @@ def get_files_in_dir(path_to_dir: str) -> list:
     return file_names
 
 
+def make_repo_id_string(repo_id: int) -> str:
+    """If repo id is int, change to string
+    Args:
+        repo_id (int/str): repo id can be int or str
+    Returns:
+        str: repo id as string type
+    """
+    if isinstance(repo_id, int):
+        repo_id = str(repo_id)
+    return repo_id
+
+
+def parameter_check_for_repo_id(repo_id):
+    """Checking for validity of repo id
+    Args:
+        repo_id (): Repository Id of omixatlas
+    Raises:
+        paramException: Error if repo id is empty or is not str or int
+    """
+    if not repo_id:
+        raise paramException(
+            title="Param Error",
+            detail="repo_id should not be empty",
+        )
+    elif type(repo_id) != str and type(repo_id) != int:
+        raise paramException(
+            title="Param Error",
+            detail="repo_id should be str or int",
+        )
+
+
 def parseInt(sin):
     """
     parsed the value passed as int  as done by js.
@@ -798,3 +883,113 @@ def replace_original_name_field(
         else:
             replaced_metadata[key] = dataset_source_info.get(key)
     return replaced_metadata
+
+
+def upload_html_file(
+    session, workspace_id: int, workspace_path: str, local_report_path: str
+):
+    """
+    Function to upload an html file to a workspace.
+    """
+    upload_url = f"https://v2.api.{session.env}.elucidata.io/workspaces/{workspace_id}/upload_url"
+    params = {"file_path": workspace_path, "content_type": "text/html"}
+    # get request to get the signed url for s3
+    response = session.get(upload_url, params=params)
+    error_handler(response)
+    attributes = response.json().get("data").get("attributes")
+    try:
+        with open(local_report_path, "rb") as file_to_upload:
+            # uploading the local file to the signed url
+            files = {"file": (local_report_path, file_to_upload)}
+            upload_response = requests.post(
+                attributes["url"], data=attributes["fields"], files=files
+            )
+            error_handler(upload_response)
+            if upload_response.status_code == http_codes.CREATED:
+                logging.basicConfig(level=logging.INFO)
+                logging.info(
+                    f"File uploaded successfully to workspace-id = {workspace_id} at path = {workspace_path}!"
+                )
+    except Exception as e:
+        raise e
+
+
+def get_report_id(session, workspace_id: int, workspace_path: str) -> str:
+    """
+    Function to return report-id of the given workspace path.
+    """
+    s3_key = make_path(workspace_id, workspace_path)
+    workspace_endpoint_url = (
+        f"https://v2.api.{session.env}.elucidata.io/v3/workspace/_search"
+    )
+    payload = {
+        "from": 0,
+        "size": 20,
+        "query": {
+            "bool": {
+                "should": [
+                    {
+                        "bool": {
+                            "must": [
+                                {"term": {"_index": {"value": "{document_index}"}}},
+                                {
+                                    "term": {
+                                        "workspace_id": {"value": f"{workspace_id}"}
+                                    }
+                                },
+                                {"term": {"s3_key": {"value": f"{s3_key}"}}},
+                            ]
+                        }
+                    },
+                    {
+                        "bool": {
+                            "must": [
+                                {"term": {"_index": {"value": "{workspace_index}"}}},
+                                {
+                                    "nested": {
+                                        "path": "permissions",
+                                        "query": {
+                                            "match": {
+                                                "permissions.user_id": {
+                                                    "query": "{user_id}"
+                                                }
+                                            }
+                                        },
+                                    }
+                                },
+                            ]
+                        }
+                    },
+                ]
+            }
+        },
+    }
+    response = session.post(workspace_endpoint_url, data=json.dumps(payload))
+    error_handler(response)
+    response_data = response.json()
+    hits = response_data.get("hits", {}).get("hits")
+    if not (hits and isinstance(hits, list)):
+        raise paramException(
+            title="Param Error",
+            detail="Incorrect workspace path / workspace_id provided. Please try again.",
+        )
+    # getting the first and only element of the list that contains data
+    data = hits[0]
+    report_id = data.get("_source", {}).get("report_id")
+    return report_id
+
+
+def get_folder_list_from_list_of_filepaths(filenames_fullpath_list: list) -> list:
+    """
+    gives back only the folders from a list of filepaths provided.
+    for example: given a list ["transcriptomics.gct","folder1/transcriptomics.gct"]
+    returned value: [".","folder1"]
+
+    Arguments:
+        filenames_fullpath_list -- list of filenames with full paths
+    """
+    list_folder_names = []
+    for full_file_path in filenames_fullpath_list:
+        folder_name = os.path.normpath(os.path.dirname(full_file_path))
+        list_folder_names.append(folder_name)
+    return list(set(list_folder_names))
